@@ -2,8 +2,7 @@ import copy
 
 import jinja2
 
-from unv.app.core import ComponentSettings
-from unv.app.settings import SETTINGS as APP_SETTINGS
+from unv.app.settings import ComponentSettings, SETTINGS as APP_SETTINGS
 
 
 class WebSettings(ComponentSettings):
@@ -14,13 +13,19 @@ class WebSettings(ComponentSettings):
             'type': 'dict',
             'required': True,
             'schema': {'enabled': {'type': 'boolean'}}
-        }
+        },
+        'link_static': {'type': 'boolean', 'required': True}
     }
     DEFAULT = {
         'autoreload': False,
+        'link_static': True,
         'jinja2': {'enabled': True},
     }
 
+    @property
+    def link_static(self):
+        return self._data['link_static']
+
     @property
     def jinja2_enabled(self):
         return self._data['jinja2']['enabled']
